@@ -94,11 +94,6 @@ def rimuovi_colonne(df, colonne):
 def seleziona_colonne(df, lista_colonne):
     return(df[lista_colonne])
 
-#make function to apply sql query on dataframe with sqldfmethod
-def sql_query(df, query):
-    import pandasql as ps
-    return(ps.sqldf(query, globals()))
-    
 
 
 
